@@ -4,7 +4,9 @@ import sys
 import converts
 
 def main():
-    import converts
+    c2f = converts.c2f()
+    f2c = converts.f2c()
+    add_temp = converts.add_temp()
     
 if __name__ == "__main__":
     main()
\ No newline at end of file
